wipe
model BasicBuilder -ndm 3 -ndf 6

source opensees.tcl
puts "fiber element ok"

source layershell.tcl
puts "layershell ok"

source rigiddigram.tcl
puts "rigiddigram ok"
fixZ 0 1 1 1 1 1 1
constraints Transformation;   				
numberer RCM;					
system SparseSYM				
test NormDispIncr 1.0e-4 2000 2; 	
algorithm NewtonLineSearch 0.75
integrator LoadControl 0.2;
analysis Static
analyze 5
puts "gravity analysis ok"
loadConst -time 0.0;

recorder Node    -file dispx.txt   -time   -nodeRange  1 16906  -dof 1 disp
recorder Node    -file dispy.txt   -time   -nodeRange  1 16906  -dof 2 disp
recorder Node    -file dispz.txt   -time   -nodeRange  1 16906  -dof 3 disp
recorder Node    -file 2176.txt   -time   -node 2176 -dof 1 disp
recorder Drift -file drift_ratio.txt  -iNode 17  18	96	490	491	492	493	494	495	496	497	498	499	500	501	502	503	504	505	506	507	508	509	510	511	512	513	514	515	516	517	518	519	520	521	522	523	524	525	526	527	528	2176	-jNode 18	96	490	491	492	493	494	495	496	497	498	499	500	501	502	503	504	505	506	507	508	509	510	511	512	513	514	515	516	517	518	519	520	521	522	523	524	525	526	527	528	2176	2211 -dof 1 -perpDirn 3
set xDamp 0.05;					# damping ratio 
set MpropSwitch 1.0;
set KcurrSwitch 0.0;
set KcommSwitch 1.0;
set KinitSwitch 0.0;
set nEigenI 1;		# mode 1
set nEigenJ 9;		# mode 3
set lambdaI 3.755438647
set lambdaJ 381.7564743
set omegaI [expr pow($lambdaI,0.5)];
set omegaJ [expr pow($lambdaJ,0.5)];
set alphaM [expr $MpropSwitch*$xDamp*(2*$omegaI*$omegaJ)/($omegaI+$omegaJ)];	# M-prop. damping; D = alphaM*M
set betaKcurr [expr $KcurrSwitch*2.*$xDamp/($omegaI+$omegaJ)];         		# current-K;      +beatKcurr*KCurrent
set betaKcomm [expr $KcommSwitch*2.*$xDamp/($omegaI+$omegaJ)];   		# last-committed K;   +betaKcomm*KlastCommitt
set betaKinit [expr $KinitSwitch*2.*$xDamp/($omegaI+$omegaJ)];         			# initial-K;     +beatKinit*Kini
# define damping
rayleigh $alphaM $betaKcurr $betaKinit $betaKcomm; 
set IDloadTag 1001;
set iGMfile "GMX.txt";
set iGMdirection "1";
set iGMfact "5.1";
set dt 0.01;
set GMfatt [expr $iGMfact];
set AccelSeries "Series -dt $dt -filePath $iGMfile -factor $GMfatt";
pattern UniformExcitation $IDloadTag $iGMdirection -accel $AccelSeries;

constraints Transformation;
numberer RCM;
#system SparseSYM
system CuSP -rTol 1e-6 -mInt 100000
test NormDispIncr 1e-3 10 2
algorithm NewtonLineSearch 0.75
integrator Newmark 0.55 0.2765625
analysis Transient
puts "ok"

set Nsteps 4000
set DtAnalysis 0.01
set TmaxAnalysis 40
set ok [analyze $Nsteps $DtAnalysis];			

if {$ok != 0} {      ;					
	set ok 0;
	set controlTime [getTime];
	while {$controlTime < $TmaxAnalysis && $ok == 0} {
		set controlTime [getTime]
		set ok [analyze 1 $DtAnalysis]
		if {$ok != 0} {
                  puts "try krylov and change test"
			test NormDispIncr   1e-2 100  2 
			algorithm  KrylovNewton 
			set ok [analyze 1 $DtAnalysis]
			test NormDispIncr 1e-3 10 2
			algorithm NewtonLineSearch 0.75
		}
		if {$ok != 0} {
                  puts "try relative"
			test RelativeNormDispIncr 0.1 10 2
			set ok [analyze 1 $DtAnalysis]
			test NormDispIncr 0.001 10 2
		}
		if {$ok != 0} {
                  puts "try relative and krylov"
			test NormDispIncr   0.001 10  2
			algorithm  KrylovNewton 
			set ok [analyze 1 $DtAnalysis]
			test NormDispIncr 0.001 10 2
			algorithm NewtonLineSearch 0.75
		}
		if {$ok != 0} {
			puts "Trying Broyden .."
			algorithm Broyden 8
			set ok [analyze 1 $DtAnalysis]
			algorithm NewtonLineSearch 0.75
		}
		if {$ok != 0} {
			puts "Trying NewtonWithLineSearch .."
			algorithm NewtonLineSearch .8
			set ok [analyze 1 $DtAnalysis]
			algorithm NewtonLineSearch 0.75
		}
	}
};      # end if ok !0

